@@ -7,7 +7,7 @@
 
 namespace Tauolapp
 {
-
+bool   Tauola::m_is_initialized  = false;
 int    Tauola::m_pdg_id          = 15;
 int    Tauola::m_firstDecayMode  = 0; 
 int    Tauola::m_secondDecayMode = 0;
@@ -84,6 +84,11 @@ void   (*Tauola::redefineTauPlusProperties)(TauolaParticle *)  = defaultRedPlus;
 void   (*Tauola::redefineTauMinusProperties)(TauolaParticle *) = defaultRedMinus;
 
 /**************************************************************/
+void Tauola::setNewCurrents(int mode)
+{
+  inirchl_(&mode);
+}
+
 double Tauola::defaultRandomGenerator(){
   return rand()*1./RAND_MAX;
 }
@@ -124,11 +129,11 @@ void Tauola::setTauLifetime(double t){
 void Tauola::initialize(){
   printf("\n");
   printf(" *************************************\n");
-  printf(" *     TAUOLA C++ Interface v1.0.7   *\n");
+  printf(" *     TAUOLA C++ Interface v1.1.10  *\n");
   printf(" *-----------------------------------*\n");
   printf(" *                                   *\n");
   printf(" *   (c) Nadia    Davidson,   (1,2)  *\n");
-  printf(" *       Gizo     Nanava,     (3)    *\n");
+  printf(" *   (c) Gizo     Nanava,     (3)    *\n");
   printf(" *       Tomasz   Przedzinski,(4)    *\n");
   printf(" *       Elzbieta Richter-Was,(2,4)  *\n");
   printf(" *       Zbigniew Was         (2,5)  *\n");
@@ -139,6 +144,19 @@ void Tauola::initialize(){
   printf(" *  4)      UJ, Krakow, Poland       *\n");
   printf(" *  5)    CERN, Geneva, Switzerland  *\n");
   printf(" *************************************\n");
+  
+  if(m_is_initialized) {
+    printf(" *                                   *\n");
+    printf(" *                                   *\n");
+    printf(" *WARNING: Tauola already initialized*\n");
+    printf(" *         reinitialization skipped  *\n");
+    printf(" *                                   *\n");
+    printf(" *                                   *\n");
+    printf(" *************************************\n");
+    return;
+  }
+
+  m_is_initialized = true;
 
   // Turn on all spin correlations
   spin_correlation.setAll(true);
@@ -555,6 +573,10 @@ void Tauola::initialise(){
   // Deprecated routines:  initialise, setInitialisePhy,
   //                       f_interface_tauolaInitialise
 }
+bool Tauola::getIsTauolaIni()
+{
+  return m_is_initialized;
+}
 
 bool Tauola::isUsingDecayOne()
 {
@@ -663,6 +685,12 @@ void Tauola::setHiggsScalarPseudoscalarMixingAngle(double angle){
 /** set the pdg code of the higgs particle which tauola should 
     treat as a scalar-pseudoscalar mix  */
 void Tauola::setHiggsScalarPseudoscalarPDG(int pdg_code){
+
+  if (particleCharge(pdg_code)!=0.0){       
+    Log::Warning()<<"You want to use spin correlations of Higgs for particle of PDGID= "<<pdg_code<<endl
+                  <<"This particle has charge="<<particleCharge(pdg_code)<<endl;   
+    Log::Fatal("This choice is not appropriate.",0);
+  }
   m_higgs_scalar_pseudoscalar_pdg=pdg_code;
 } 
 
@@ -707,4 +735,75 @@ void Tauola::summary()
   dekay_(&sign_type,pol);
 }
 
+void Tauola::fill_val(int beg, int end, double* array, double value) 
+{
+  for (int i = beg; i < end; i++)
+    array[i] = value;
+}
+
+double Tauola::particleCharge(int idhep)
+{
+  static double CHARGE[101] = { 0 };
+  static int j=0;  
+  //--
+  //--   Array 'SPIN' contains the spin  of  the first 100 particles accor-
+  //--   ding to the PDG particle code...
+
+  if(j==0) // initialization
+    {   
+      j=1;
+      fill_val(0 ,  1, CHARGE, 0.0         );
+      fill_val(1 ,  2, CHARGE,-0.3333333333);
+      fill_val(2 ,  3, CHARGE, 0.6666666667);
+      fill_val(3 ,  4, CHARGE,-0.3333333333);
+      fill_val(4 ,  5, CHARGE, 0.6666666667);
+      fill_val(5 ,  6, CHARGE,-0.3333333333);
+      fill_val(6 ,  7, CHARGE, 0.6666666667);
+      fill_val(7 ,  8, CHARGE,-0.3333333333);
+      fill_val(8 ,  9, CHARGE, 0.6666666667);
+      fill_val(9 , 11, CHARGE, 0.0         );
+      fill_val(11 ,12, CHARGE,-1.0         );
+      fill_val(12 ,13, CHARGE, 0.0         );
+      fill_val(13 ,14, CHARGE,-1.0         );
+      fill_val(14, 15, CHARGE, 0.0         );
+      fill_val(15 ,16, CHARGE,-1.0         );
+      fill_val(16, 17, CHARGE, 0.0         );
+      fill_val(17 ,18, CHARGE,-1.0         );
+      fill_val(18, 24, CHARGE, 0.0         );
+      fill_val(24, 25, CHARGE, 1.0         );
+      fill_val(25, 37, CHARGE, 0.0         );
+      fill_val(37, 38, CHARGE, 1.0         );
+      fill_val(38,101, CHARGE, 0.0         );
+    }
+
+  int idabs=abs(idhep);
+  double phoch=0.0;
+
+  //--
+  //--   Charge of quark, lepton, boson etc....
+  if (idabs<=100) phoch=CHARGE[idabs];
+  else {
+    int Q3= idabs/1000 % 10;
+    int Q2= idabs/100  % 10;
+    int Q1= idabs/10   % 10;
+    if (Q3==0){
+      //--
+      //-- ...meson...
+      if(Q2 % 2==0) phoch=CHARGE[Q2]-CHARGE[Q1];
+      else          phoch=CHARGE[Q1]-CHARGE[Q2];
+    }
+    else{
+      //--
+      //--   ...diquarks or baryon.
+      phoch=CHARGE[Q1]+CHARGE[Q2]+CHARGE[Q3];
+    }
+  }
+  //--
+  //--   Find the sign of the charge...
+  if (idhep<0.0) phoch=-phoch;
+  if (phoch*phoch<0.000001) phoch=0.0;
+  
+  return phoch;
+}
+
 } // namespace Tauolapp
