@@ -588,6 +588,7 @@ C                       COSTHE  -- cosine of angle between tau+ and 1st beam
 C                       TA,TB   -- helicity states of tau+ tau-
 C
 C     called by : BORNY, BORAS, BORNV, WAGA, WEIGHT
+C     WARNING: temporarily tau-mass terms inactivated, Dec 10, 2019     
 C ----------------------------------------------------------------------
       IMPLICIT REAL*8(A-H,O-Z)
       COMMON / T_BEAMPM / ENE ,AMIN,AMFIN,IDE,IDF
@@ -633,18 +634,35 @@ C ** PROPAGATORS
         COST0=COSTHE
         SINTHE=SQRT(1.D0-COSTHE**2)
         BETA=SQRT(MAX(0D0,1D0-4D0*AMFIN**2/SVAR))
+        BETA=1.0 ! zbw 10.12.2019 necessary kill for tauspinner electroweak
 C I MULTIPLY AXIAL COUPLING BY BETA FACTOR.
-        XUPZFP(1)=0.5D0*(XUPZF(1)+XUPZF(2))+0.5*BETA*(XUPZF(1)-XUPZF(2))
-        XUPZFP(2)=0.5D0*(XUPZF(1)+XUPZF(2))-0.5*BETA*(XUPZF(1)-XUPZF(2))
-        XUPZIP(1)=0.5D0*(XUPZI(1)+XUPZI(2))+0.5*(XUPZI(1)-XUPZI(2))
-        XUPZIP(2)=0.5D0*(XUPZI(1)+XUPZI(2))-0.5*(XUPZI(1)-XUPZI(2))
+        XUPZFP(1)=0.5D0*(XUPZF(1)+XUPZF(2))+0.5D0*BETA*(XUPZF(1)-XUPZF(2))
+        XUPZFP(2)=0.5D0*(XUPZF(1)+XUPZF(2))-0.5D0*BETA*(XUPZF(1)-XUPZF(2))
+        XUPZIP(1)=0.5D0*(XUPZI(1)+XUPZI(2))+0.5D0*(XUPZI(1)-XUPZI(2))
+        XUPZIP(2)=0.5D0*(XUPZI(1)+XUPZI(2))-0.5D0*(XUPZI(1)-XUPZI(2))
 C FINAL STATE VECTOR COUPLING
         XUPF     =0.5D0*(XUPZF(1)+XUPZF(2))
         XUPI     =0.5D0*(XUPZI(1)+XUPZI(2))
         XTHING   =0D0
 
         PROPA =1D0/SVAR
-        PROPZ =1D0/DCMPLX(SVAR-AMZ**2,SVAR/AMZ*GAMMZ)
+        PROPA =PROPA *(137.03604D0/128.86674175D0) ! poor man's alpha running 
+                                                   ! corr.: alpha(m_z)/alpha(0)
+                                                   ! t_born is called 
+                                                   ! in tau_reweight_lib.cxx
+                                                   ! not perfect choice 
+                                                   ! for sig of small SVAR's,
+                                                   ! but spin correlations OK.
+        PROPZ =1D0/DCMPLX(SVAR-AMZ**2,AMZ*GAMMZ)
+ ! zbw Dec 10, 2019 : residuum of Z adjusted now to effective born
+        GFERMI = 1.166389E-5
+        ALPHAINV=128.86674175 !137.03604D0
+        ZetVPi =  Gfermi *AMZ**2 *ALPHAINV /(DSQRT(2.d0)*8.d0*PI)
+     $       *(SWSQ*(1d0-SWSQ)) *16d0
+        PROPZ =PROPZ *ZetVPi
+        PROPZ =PROPZ *(137.03604D0/128.86674175D0)       
+!        PROPA=PROPA*1.037
+!      write(*,*) 'GF=',gfermi,' ',ALPHAINV,' ',swsq,' ',amz,' == ',ZetVPi
         IF (KEYGSW.EQ.0) PROPZ=0.D0
         DO 50 I=1,2
          DO 50 J=1,2
@@ -689,14 +707,13 @@ C
       IF (SVAR.GT.4D0*AMFIN**2) THEN
 C PHASE SPACE THRESHOLD FACTOR
         THRESH=SQRT(1-4D0*AMFIN**2/SVAR)
+!        desactivated, necessary for not anymore recommended solution !
+!        THRESH=1.D0 ! zbw 10.12.2019 necessary kill for tauspinner electroweak
         T_BORN= FUNT*SVAR**2*THRESH
       ELSE
         THRESH=0.D0
         T_BORN=0.D0
       ENDIF
-C ZW HERE WAS AN ERROR 19. 05. 1989
-!      write(*,*) 'KKKK ',PROPA,PROPZ,XUPGI,XUPGF,XUPZI,XUPZF
-!      write(*,*) 'KKKK X',svar,costhe,TA,TB,T_BORN
       END
 
       SUBROUTINE INITWK(IDEX,IDFX,SVAR)
@@ -720,9 +737,9 @@ C     GAMMZ       = Z0 width
 C
       ENE=SQRT(SVAR)/2
       AMIN=0.511D-3
-      SWSQ=0.23147
-      AMZ=91.1882
-      GAMMZ=2.4952
+      SWSQ=0.2315200D0 ! 0.23147
+      AMZ=91.18870000000D0! 91.1882
+      GAMMZ=2.4952D0
       IF     (IDFX.EQ. 15) then       
         IDF=2  ! denotes tau +2 tau-
         AMFIN=1.77703 !this mass is irrelevant if small, used in ME only
